@@ -21,6 +21,7 @@ export class VideoPlayer extends Component {
 		onChange: PropTypes.func,
 		...View.propTypes
 	};
+
 	static defaultProps = {
 		play: false,
 		replay: false,
@@ -29,6 +30,21 @@ export class VideoPlayer extends Component {
 		currentTime: 0,
 		startTime: 0,
 	};
+
+	static Constants = {
+		quality: {
+			QUALITY_LOW: 'low',
+			QUALITY_MEDIUM: 'medium',
+			QUALITY_HIGHEST: 'highest',
+			QUALITY_640x480: '640x480',
+			QUALITY_960x540: '960x540',
+			QUALITY_1280x720: '1280x720',
+			QUALITY_1920x1080: '1920x1080',
+			QUALITY_3840x2160: '3840x2160', // available in iOS 9
+			QUALITY_PASS_THROUGH: 'passthrough', // does not change quality
+		}
+	};
+
 	constructor(...args) {
 		super(...args);
 		this.state = {};
@@ -70,10 +86,20 @@ export class VideoPlayer extends Component {
 		this.props.onChange(event);
 	}
 
-	trim(source, start, end) {
+	trim(source, options = {}) {
+		const availableQualities = Object.values(VideoPlayer.Constants.quality);
+		if (!options.hasOwnProperty('startTime')) {
+			console.warn('Start time is not specified');
+		}
+		if (!options.hasOwnProperty('endTime')) {
+			console.warn('End time is not specified');
+		}
+		if (options.hasOwnProperty('quality') && !availableQualities.includes(options.quality)) {
+			console.warn('Quality is wrong, Please use VideoPlayer.Constants.quality');
+		}
 		const actualSource = getActualSource(source);
 		return new Promise((resolve, reject) => {
-			RNVideoTrimmer.trim(actualSource, start, end, (err, output) => {
+			RNVideoTrimmer.trim(actualSource, options, (err, output) => {
 				if (err) {
 					return reject(err);
 				}
